@@ -35,7 +35,7 @@ test_that("correct functioning of check_date_restriction_requirements", {
   source_system_name <- "exampleCSV_source"
   target_system_name <- "exampleCSV_target"
 
-  DIZutils::cleanup_old_logfile(logfile_dir = tempdir())
+  DIZtools::cleanup_old_logfile(logfile_dir = tempdir())
 
   res <- check_date_restriction_requirements(
     mdr = mdr,
